@@ -23,6 +23,7 @@
 #include <kidentitymanagement_export.h>
 #include <kconfiggroup.h>
 #include <QObject>
+#include <QVector>
 
 class QStringList;
 
@@ -57,8 +58,8 @@ public:
     static IdentityManager *self();
 
 public:
-    typedef QList<Identity>::Iterator Iterator;
-    typedef QList<Identity>::ConstIterator ConstIterator;
+    typedef QVector<Identity>::Iterator Iterator;
+    typedef QVector<Identity>::ConstIterator ConstIterator;
 
     /**
      * Typedef for STL style iterator
