@@ -15,7 +15,7 @@
     Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KIDENTITYMANAGER_SIGNATURECONFIGURATOR_H
@@ -48,7 +48,7 @@ public:
     ~SignatureConfigurator() override;
 
     /**
-      * Enum for the different viemodes.
+      * Enum for the different viewmodes.
       */
     enum ViewMode {
         ShowCode, ShowHtml
@@ -110,7 +110,7 @@ public:
     void setCommandURL(const QString &url);
 
     /**
-       Conveniece method.
+       Convenience method.
        @return a Signature object representing the state of the widgets.
      **/
     Q_REQUIRED_RESULT Signature signature() const;
@@ -143,7 +143,7 @@ public:
     void setImageLocation(const Identity &identity);
 
 private:
-    void slotEnableEditButton(const QString &);
+    void slotUrlChanged();
     void slotEdit();
     void slotSetHtml();
 
